=== modified file 'drizzled/field/datetime.cc'
--- drizzled/field/datetime.cc	2009-03-08 23:45:12 +0000
+++ drizzled/field/datetime.cc	2009-06-29 06:38:07 +0000
@@ -134,7 +134,8 @@
     char tmp_string[MAX_DATE_STRING_REP_LENGTH];
     size_t tmp_string_len;
 
-    temporal.to_string(tmp_string, &tmp_string_len);
+    tmp_string_len= temporal.to_string(tmp_string, MAX_DATE_STRING_REP_LENGTH);
+    assert(tmp_string_len < MAX_DATE_STRING_REP_LENGTH);
     my_error(ER_INVALID_DATETIME_VALUE, MYF(ME_FATALERROR), tmp_string);
     return 1;
   }

=== modified file 'drizzled/field/timestamp.cc'
--- drizzled/field/timestamp.cc	2009-04-28 21:46:57 +0000
+++ drizzled/field/timestamp.cc	2009-06-29 06:38:07 +0000
@@ -230,8 +230,9 @@
 {
   uint32_t temp;
   char *to;
+  int to_len= field_length + 1;
 
-  val_buffer->alloc(field_length + 1);
+  val_buffer->alloc(to_len);
   to= (char *) val_buffer->ptr();
 
 #ifdef WORDS_BIGENDIAN
@@ -245,10 +246,12 @@
 
   drizzled::Timestamp temporal;
   (void) temporal.from_time_t((time_t) temp);
-  size_t to_len;
-
-  temporal.to_string(to, &to_len);
-  val_buffer->length((uint32_t) to_len);
+
+  int rlen;
+  rlen= temporal.to_string(to, to_len);
+  assert(rlen < to_len);
+
+  val_buffer->length(to_len);
   return val_buffer;
 }
 

=== modified file 'drizzled/function/time/date.cc'
--- drizzled/function/time/date.cc	2009-02-14 19:02:06 +0000
+++ drizzled/function/time/date.cc	2009-06-29 06:38:07 +0000
@@ -38,9 +38,10 @@
   }
 
   /* Convert the Date to a string and return it */
-  size_t new_length;
-  temporal.to_string(str->c_ptr(), &new_length);
-  str->length((uint32_t) new_length);
+  int new_length;
+  new_length= temporal.to_string(str->c_ptr(), MAX_DATE_STRING_REP_LENGTH);
+  assert(new_length < MAX_DATE_STRING_REP_LENGTH);
+  str->length(new_length);
   return str;
 }
 

=== modified file 'drizzled/function/time/unix_timestamp.cc'
--- drizzled/function/time/unix_timestamp.cc	2009-03-05 02:07:55 +0000
+++ drizzled/function/time/unix_timestamp.cc	2009-06-29 06:38:07 +0000
@@ -64,8 +64,9 @@
   {
     null_value= true;
     char buff[MAX_DATETIME_WIDTH];
-    size_t buff_len;
-    temporal.to_string(buff, &buff_len);
+    int buff_len;
+    buff_len= temporal.to_string(buff, MAX_DATETIME_WIDTH);
+    assert(buff_len < MAX_DATETIME_WIDTH);
     buff[buff_len]= '\0';
     my_error(ER_INVALID_UNIX_TIMESTAMP_VALUE, MYF(0), buff);
     return 0;

=== modified file 'drizzled/opt_range.cc'
--- drizzled/opt_range.cc	2009-06-23 19:57:38 +0000
+++ drizzled/opt_range.cc	2009-06-29 06:38:07 +0000
@@ -4588,7 +4588,9 @@
           size_t new_value_length;
           String new_value_string(new_value_buff, sizeof(new_value_buff), &my_charset_bin);
 
-          min_timestamp.to_string(new_value_string.c_ptr(), &new_value_length);
+          new_value_length= min_timestamp.to_string(new_value_string.c_ptr(),
+						    MAX_DATETIME_FULL_WIDTH);
+	  assert(new_value_length < MAX_DATETIME_FULL_WIDTH);
           new_value_string.length(new_value_length);
           err= value->save_str_value_in_field(field, &new_value_string);
         }
@@ -4599,10 +4601,12 @@
            * to the higher bound of the epoch.
            */
           char new_value_buff[MAX_DATETIME_FULL_WIDTH];
-          size_t new_value_length;
+          int new_value_length;
           String new_value_string(new_value_buff, sizeof(new_value_buff), &my_charset_bin);
 
-          max_timestamp.to_string(new_value_string.c_ptr(), &new_value_length);
+          new_value_length= max_timestamp.to_string(new_value_string.c_ptr(),
+						    MAX_DATETIME_FULL_WIDTH);
+	  assert(new_value_length < MAX_DATETIME_FULL_WIDTH);
           new_value_string.length(new_value_length);
           err= value->save_str_value_in_field(field, &new_value_string);
         }

=== modified file 'drizzled/temporal.cc'
--- drizzled/temporal.cc	2009-04-27 20:11:16 +0000
+++ drizzled/temporal.cc	2009-06-29 06:38:07 +0000
@@ -1184,63 +1184,48 @@
     return is_valid();
 }
 
-void Time::to_string(char *to, size_t *to_len) const
-{
-  *to_len= sprintf(to
-                 , "%02" PRIu32 ":%02" PRIu32 ":%02" PRIu32
-                 , _hours
-                 , _minutes
-                 , _seconds);
-}
-
-void Date::to_string(char *to, size_t *to_len) const
-{
-  *to_len= sprintf(to
-                 , "%04" PRIu32 "-%02" PRIu32 "-%02" PRIu32
-                 , _years
-                 , _months
-                 , _days);
-}
-
-void DateTime::to_string(char *to, size_t *to_len) const
+int Time::to_string(char *to, size_t to_len) const
+{
+  return snprintf(to, to_len,
+		  "%02" PRIu32 ":%02" PRIu32 ":%02" PRIu32,
+		  _hours, _minutes, _seconds);
+}
+
+int Date::to_string(char *to, size_t to_len) const
+{
+  return snprintf(to, to_len,
+		  "%04" PRIu32 "-%02" PRIu32 "-%02" PRIu32,
+		  _years, _months, _days);
+}
+
+int DateTime::to_string(char *to, size_t to_len) const
 {
   /* If the temporal has a microsecond component, use a slightly different output */
   if (_useconds == 0)
   {
-    *to_len= sprintf(to
-                  , "%04" PRIu32 "-%02" PRIu32 "-%02" PRIu32 " %02" PRIu32 ":%02" PRIu32 ":%02" PRIu32
-                  , _years
-                  , _months
-                  , _days
-                  , _hours
-                  , _minutes
-                  , _seconds);
+    return snprintf(to, to_len,
+		    "%04" PRIu32 "-%02" PRIu32 "-%02" PRIu32
+		          " %02" PRIu32 ":%02" PRIu32 ":%02" PRIu32,
+		    _years, _months, _days,
+		    _hours, _minutes, _seconds);
   }
   else
   {
-    *to_len= sprintf(to
-                  , "%04" PRIu32 "-%02" PRIu32 "-%02" PRIu32 " %02" PRIu32 ":%02" PRIu32 ":%02" PRIu32 ".%06" PRIu32
-                  , _years
-                  , _months
-                  , _days
-                  , _hours
-                  , _minutes
-                  , _seconds
-                  , _useconds);
+    return snprintf(to, to_len,
+		    "%04" PRIu32 "-%02" PRIu32 "-%02" PRIu32
+		       " %02" PRIu32 ":%02" PRIu32 ":%02" PRIu32 ".%06" PRIu32,
+		    _years, _months, _days,
+		    _hours, _minutes, _seconds, _useconds);
   }
 }
 
-void MicroTimestamp::to_string(char *to, size_t *to_len) const
+int MicroTimestamp::to_string(char *to, size_t to_len) const
 {
-  *to_len= sprintf(to
-                 , "%04" PRIu32 "-%02" PRIu32 "-%02" PRIu32 " %02" PRIu32 ":%02" PRIu32 ":%02" PRIu32 ".%06" PRIu32
-                 , _years
-                 , _months
-                 , _days
-                 , _hours
-                 , _minutes
-                 , _seconds
-                 , _useconds);
+  return snprintf(to, to_len,
+		  "%04" PRIu32 "-%02" PRIu32 "-%02" PRIu32
+		      " %02" PRIu32 ":%02" PRIu32 ":%02" PRIu32 ".%06" PRIu32,
+		  _years, _months, _days,
+		  _hours, _minutes, _seconds, _useconds);
 }
 
 void Time::to_decimal(my_decimal *to) const

=== modified file 'drizzled/temporal.h'
--- drizzled/temporal.h	2009-03-05 07:15:28 +0000
+++ drizzled/temporal.h	2009-06-29 06:38:07 +0000
@@ -331,9 +331,12 @@
    * value.
    *
    * @param C-String to fill.
-   * @param Length of filled string (out param)
+   * @param Length of to C-String
+   * @returns length of string written (not including trailing '\0').
+   *          If output was truncated, returns length that would have
+   *          been outputted.
    */
-  virtual void to_string(char *to, size_t *to_len) const;
+  virtual int to_string(char *to, size_t to_len) const;
 
   /**
    * Attempts to populate the Date instance based
@@ -503,10 +506,13 @@
    * string representation of the Time
    * value.
    *
-   * @param C-String to fill.
-   * @param Length of filled string (out param)
+   * @param C-String to fill
+   * @param Length of to C-String
+   * @returns length of string written (not including trailing '\0').
+   *          If output was truncated, returns length that would have
+   *          been outputted.
    */
-  void to_string(char *to, size_t *to_len) const;
+  int to_string(char *to, size_t to_len) const;
 
   /**
    * Attempts to populate the Time instance based
@@ -598,10 +604,13 @@
    * string representation of the DateTime
    * value.
    *
-   * @param C-String to fill.
-   * @param Length of filled string (out param)
+   * @param C-String to fill
+   * @param Length of to C-String
+   * @returns length of string written (not including trailing '\0').
+   *          If output was truncated, returns length that would have
+   *          been outputted.
    */
-  virtual void to_string(char *to, size_t *to_len) const;
+  virtual int to_string(char *to, size_t to_len) const;
 
   /**
    * Attempts to populate the DateTime instance based
@@ -747,10 +756,13 @@
    * string representation of the MicroTimestamp
    * value.
    *
-   * @param C-String to fill.
-   * @param Length of filled string (out param)
+   * @param C-String to fill
+   * @param Length of to C-String
+   * @returns length of string written (not including trailing '\0').
+   *          If output was truncated, returns length that would have
+   *          been outputted.
    */
-  void to_string(char *to, size_t *to_len) const;
+  int to_string(char *to, size_t to_len) const;
 
   /**
    * Fills a supplied timeval pointer with an

